@@ -10,11 +10,6 @@ import requests
 import requests_cache
 from bs4 import BeautifulSoup
 
-cache_enabled = True
-if cache_enabled:
-    print("Cache Enabled")
-    requests_cache.install_cache('cache', expire_after=3600)
-
 
 def remove_duplicates(lis):
     """
@@ -33,13 +28,17 @@ numbers = ["1", "2", "3", "4", "5", "6", "7", "8", "9", "0"]
 
 
 class BaseIserv:
-    def __init__(self, url, username, password):
+    def __init__(self, url, username, password, cache=False):
         self.username = username
         self.password = password
         self.time_to_next_substitution_request = 0
         self.url = url
         self.session = requests.Session()
 
+        if cache:
+            print("Cache Enabled")
+            requests_cache.install_cache('cache', expire_after=3600)
+
     def _login(self):
         headers = {'User-Agent': 'Mozilla/5.0'}
         payload = {'_username': self.username, '_password': self.password}
@@ -90,6 +89,10 @@ class Task(BaseIserv):
 
 
 class Iserv(BaseIserv):
+    def get_home(self):
+        self._login()
+        return self.session.get(f"{self.url}/iserv")
+
     def get_untis_substitution_plan(self, path, schoolclass):
         """
         Gets untis substitution plan data for a given class.
@@ -101,14 +104,13 @@ class Iserv(BaseIserv):
         plan_soup = BeautifulSoup(res.text, 'lxml')
         rows = []
         for row in plan_soup.find_all('tr', class_='list'):
-            pattern = Template('^$number.*$char.*$')
+            pattern = Template('(.*|^)$number.*$char.*$')
             rowlist = []
             for i in row:
                 rowlist.append(i.text)
             if len(rowlist) < 2:
                 continue
             currentclass = rowlist[4].strip()
-
             patternresult = re.search(pattern.safe_substitute(number=schoolclass[0], char=schoolclass[1]), currentclass)
             if patternresult and currentclass[0] in numbers or currentclass == schoolclass:
                 text = []
@@ -168,7 +170,7 @@ class Iserv(BaseIserv):
             test_list.append(entry)
         return test_list
 
-    def get_tasks(self, path="/iserv/exercise?thefuckdontaskwhytryremoveitandyouwillbreakeverything=true"):
+    def get_tasks(self, path="/iserv/exercise?filter[status]=current"):
         """
         Returns a dict of tasks for the current user
         """
@@ -179,11 +181,10 @@ class Iserv(BaseIserv):
         res = self.session.get(self.url + path)
         soup = BeautifulSoup(res.text, 'lxml')
         task_table = soup.find("table", {"id": "crud-table"})
-        # print(task_table)
         rows = task_table.find_all("tr")
         for row in rows:
             columns = row.find_all("td")
-            if len(columns) == 5:
+            if len(columns) == 6:
                 task = Task(self.url, self.username, self.password)
                 task.title = columns[0].find("a").text
                 task.id = int(columns[0].find("a")["href"].split("/")[-1])
